pub trait AppState:
Any
+ Send
+ Sync
+ Debug
+ Downcast { }Expand description
Trait for application state managed by the Runtime.
Any type that is Send + Sync + Debug + 'static can serve as application
state. The runtime stores at most one instance of each concrete type.
Example
ⓘ
#[derive(Debug, Default)]
struct TodoList {
items: Vec<String>,
}
impl AppState for TodoList {}
// Register with the runtime:
runtime.add_app_state(Box::new(TodoList::default()))?;Implementations
Sourceimpl dyn AppState
impl dyn AppState
Sourcepub fn is<__T: AppState>(&self) -> bool
pub fn is<__T: AppState>(&self) -> bool
Returns true if the trait object wraps an object of type __T.
Sourcepub fn downcast<__T: AppState>(self: Box<Self>) -> Result<Box<__T>, Box<Self>>
pub fn downcast<__T: AppState>(self: Box<Self>) -> Result<Box<__T>, Box<Self>>
Returns a boxed object from a boxed trait object if the underlying object is of type
__T. Returns the original boxed trait if it isn’t.
Sourcepub fn downcast_rc<__T: AppState>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>
pub fn downcast_rc<__T: AppState>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>
Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of
type __T. Returns the original Rc-ed trait if it isn’t.
Sourcepub fn downcast_ref<__T: AppState>(&self) -> Option<&__T>
pub fn downcast_ref<__T: AppState>(&self) -> Option<&__T>
Returns a reference to the object within the trait object if it is of type __T, or
None if it isn’t.
Sourcepub fn downcast_mut<__T: AppState>(&mut self) -> Option<&mut __T>
pub fn downcast_mut<__T: AppState>(&mut self) -> Option<&mut __T>
Returns a mutable reference to the object within the trait object if it is of type
__T, or None if it isn’t.