pub enum ScrollAlignment {
Start,
Center,
End,
Nearest,
Fraction(f32),
}Expand description
Desired placement of a target inside a scroll viewport.
Variants
Start
Align the target’s leading edge with the viewport’s leading edge.
Center
Center the target in the viewport.
End
Align the target’s trailing edge with the viewport’s trailing edge.
Nearest
Use the smallest scroll delta that makes the target visible.
Fraction(f32)
Place the target at a fractional position in the viewport.
0.0 behaves like ScrollAlignment::Start, 0.5 centers the target,
and 1.0 behaves like ScrollAlignment::End.