pub struct ReqId(pub u64);Expand description
An opaque request identifier assigned to each emitted effect.
The platform executor returns this id when delivering the result so the runtime can correlate responses.
Tuple Fields
0: u64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ReqId
impl<'de> Deserialize<'de> for ReqId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Ord for ReqId
impl Ord for ReqId
Sourceimpl PartialOrd for ReqId
impl PartialOrd for ReqId
impl Copy for ReqId
impl Eq for ReqId
impl StructuralPartialEq for ReqId