LayoutOp

Enum LayoutOp 

pub enum LayoutOp {
Show 17 variants Box { width: Option<f32>, height: Option<f32>, min_width: Option<f32>, max_width: Option<f32>, min_height: Option<f32>, max_height: Option<f32>, padding: [f32; 4], flex_grow: f32, flex_shrink: f32, aspect_ratio: Option<f32>, }, StyledBox { style: BoxStyle, flex_grow: f32, flex_shrink: f32, }, Flex { direction: FlexDirection, wrap: FlexWrap, flex_grow: f32, flex_shrink: f32, padding: [f32; 4], gap: Option<f32>, align_items: AlignItems, justify_content: JustifyContent, }, Grid { columns: Vec<GridTrack>, rows: Vec<GridTrack>, column_gap: Option<f32>, row_gap: Option<f32>, padding: [f32; 4], }, GridItem { row_start: GridPlacement, row_end: GridPlacement, col_start: GridPlacement, col_end: GridPlacement, }, Responsive { query: ResponsiveQuery, cases: Vec<ResponsiveCondition>, }, Scroll { direction: FlexDirection, show_scrollbar: bool, width: Option<f32>, height: Option<f32>, min_width: Option<f32>, max_width: Option<f32>, min_height: Option<f32>, max_height: Option<f32>, padding: [f32; 4], flex_grow: f32, flex_shrink: f32, }, Embed { kind: EmbedKind, widget_id: WidgetId, width: Option<f32>, height: Option<f32>, }, AbsoluteFill, Positioned { left: Option<f32>, top: Option<f32>, right: Option<f32>, bottom: Option<f32>, width: Option<f32>, height: Option<f32>, }, PositionedLengths { left: Option<Length>, top: Option<Length>, right: Option<Length>, bottom: Option<Length>, width: Option<Length>, height: Option<Length>, }, ZStack, Align, Flyout { anchor: WidgetId, content: WidgetId, }, Spotlight { anchor: WidgetId, padding: f32, }, Transform { transform: [f32; 16], }, Clip { path: Option<String>, },
}

Variants



Box

Fields

width: Option<f32>
height: Option<f32>
min_width: Option<f32>
max_width: Option<f32>
min_height: Option<f32>
max_height: Option<f32>
padding: [f32; 4]
flex_grow: f32
flex_shrink: f32
aspect_ratio: Option<f32>


StyledBox

A common box using declarative length expressions.

Fields

style: BoxStyle
flex_grow: f32
flex_shrink: f32


Flex

Fields

direction: FlexDirection
flex_grow: f32
flex_shrink: f32
padding: [f32; 4]
align_items: AlignItems
justify_content: JustifyContent


Grid

Fields

columns: Vec<GridTrack>
column_gap: Option<f32>
row_gap: Option<f32>
padding: [f32; 4]


GridItem

Fields

row_start: GridPlacement
col_start: GridPlacement


Responsive

Selects one case child or the final fallback child from local constraints.



Scroll

Fields

direction: FlexDirection
show_scrollbar: bool
width: Option<f32>
height: Option<f32>
min_width: Option<f32>
max_width: Option<f32>
min_height: Option<f32>
max_height: Option<f32>
padding: [f32; 4]
flex_grow: f32
flex_shrink: f32


Embed

Fields

widget_id: WidgetId
width: Option<f32>
height: Option<f32>


AbsoluteFill



Positioned

Fields

left: Option<f32>
right: Option<f32>
bottom: Option<f32>
width: Option<f32>
height: Option<f32>


PositionedLengths

Absolutely positions a child using typed lengths resolved by layout.

Fields

bottom: Option<Length>
height: Option<Length>


ZStack



Align



Flyout

Fields

anchor: WidgetId
content: WidgetId


Spotlight

Lays out five overlay children around an external anchor.

Children are ordered as top, bottom, left, right, and focus ring. The four surrounding regions leave the padded anchor rectangle uncovered.

Fields

anchor: WidgetId
padding: f32


Transform

Fields

transform: [f32; 16]


Clip

Fields