pub enum MaxLengthEnforcement {
None,
Enforced,
AfterComposition,
}Expand description
Whether the framework should enforce max_length during editing.
Variants
None
Enforced
AfterComposition
Allow the active composing value to exceed the limit and enforce it once the input method commits.