pub struct DragSessionState {
pub source_node: Option<WidgetId>,
pub source_identifier: Option<String>,
pub payload: DragSessionPayload,
pub point: LayoutPoint,
pub target_node: Option<WidgetId>,
pub target_identifier: Option<String>,
}Expand description
Runtime-only state for a drag gesture currently in progress.
Fields
source_node: Option<WidgetId>Semantics node that started the drag, when this is an internal drag.
source_identifier: Option<String>Stable source identifier, if supplied by the drag source widget.
payload: DragSessionPayloadPayload carried by the drag.
point: LayoutPointPointer position in layout coordinates.
target_node: Option<WidgetId>Target currently under the pointer that advertises a drop action.
target_identifier: Option<String>Stable target identifier, if supplied by the drop target widget.