pub enum TextEditingConvention {
Standard,
Apple,
}Expand description
Host text-editing conventions used by platform input controllers.
This is supplied by the runtime rather than inferred from the Rust target: a WebAssembly application can be running on either an Apple or non-Apple host.
Variants
Standard
Control is the primary shortcut and word-navigation modifier.
Apple
Command is the primary shortcut, Option navigates by word, and the conventional Control-based line-editing commands are available.
Implementations
Sourceimpl TextEditingConvention
impl TextEditingConvention
pub const fn is_apple(self) -> bool
pub const fn primary_shortcut_modifier(self) -> u8
pub const fn has_primary_shortcut(self, modifiers: u8) -> bool
pub const fn has_word_modifier(self, modifiers: u8) -> bool