video_file

Macro video_file 

macro_rules! video_file {
    ($path:expr $(,)?) => { ... };
}
Creates a Video from a compile-time local file path and fails compilation when that path cannot be resolved by include_bytes!.

Relative paths are resolved the same way as include_bytes!: relative to the source file that invokes this macro.