pub enum MotionPhase {
Layout,
Composite,
Paint,
}Expand description
The rendering stage affected by a motion track.
Composite motion is the cheapest path and should be preferred for opacity, translate, scale, and rotation. Layout and paint tracks are declarative inputs for shells that can animate size, position, color, or drawing data.
Variants
Layout
The track affects layout values such as width or height.
Composite
The track affects compositor values such as opacity or transform.
Paint
The track affects paint-only values such as color.