pub enum MotionPredicate {
Hovered(WidgetId),
Pressed(WidgetId),
Focused(WidgetId),
Disabled(WidgetId),
}Expand description
Runtime interaction predicate that can branch inside a MotionExpr.
Predicates are evaluated by the shell from deterministic runtime state, not by calling user code every frame.
Variants
Hovered(WidgetId)
True when the widget is currently hovered.
Pressed(WidgetId)
True when the widget is currently pressed.
Focused(WidgetId)
True when the widget is currently focused.
Disabled(WidgetId)
True when the widget is disabled.