pub enum AlignItems {
Start,
End,
Center,
Stretch,
Baseline,
}Expand description
How children are aligned on the cross axis of a flex container.
Equivalent to the CSS align-items property.
Defaults to Stretch.
Variants
Start
Align children to the start of the cross axis.
End
Align children to the end of the cross axis.
Center
Center children on the cross axis.
Stretch
Stretch children to fill the cross axis. This is the default.
Baseline
Align children so their text baselines line up.