pub struct DeepLinkReceived {
pub link: DeepLink,
}Expand description
Built-in action dispatched by shells when a deep link is received.
Fields
link: DeepLinkTrait Implementations
Sourceimpl Action for DeepLinkReceived
impl Action for DeepLinkReceived
Sourceimpl Clone for DeepLinkReceived
impl Clone for DeepLinkReceived
Sourcefn clone(&self) -> DeepLinkReceived
fn clone(&self) -> DeepLinkReceived
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeepLinkReceived
impl Debug for DeepLinkReceived
Sourceimpl<'de> Deserialize<'de> for DeepLinkReceived
impl<'de> Deserialize<'de> for DeepLinkReceived
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DeepLinkReceived
impl PartialEq for DeepLinkReceived
Sourcefn eq(&self, other: &DeepLinkReceived) -> bool
fn eq(&self, other: &DeepLinkReceived) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DeepLinkReceived
impl Serialize for DeepLinkReceived
impl Eq for DeepLinkReceived
impl StructuralPartialEq for DeepLinkReceived