pub struct NotificationPermissionRequest {
pub alerts: bool,
pub badge: bool,
pub sound: bool,
pub provisional: bool,
}Expand description
Request sent when an app asks the host to request notification permission.
Fields
alerts: boolbadge: boolsound: boolprovisional: boolTrait Implementations
Sourceimpl Clone for NotificationPermissionRequest
impl Clone for NotificationPermissionRequest
Sourcefn clone(&self) -> NotificationPermissionRequest
fn clone(&self) -> NotificationPermissionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for NotificationPermissionRequest
impl Default for NotificationPermissionRequest
Sourcefn default() -> NotificationPermissionRequest
fn default() -> NotificationPermissionRequest
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for NotificationPermissionRequest
impl<'de> Deserialize<'de> for NotificationPermissionRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for NotificationPermissionRequest
impl PartialEq for NotificationPermissionRequest
Sourcefn eq(&self, other: &NotificationPermissionRequest) -> bool
fn eq(&self, other: &NotificationPermissionRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for NotificationPermissionRequest
impl StructuralPartialEq for NotificationPermissionRequest