pub struct NotificationResponseReceived {
pub response: NotificationResponse,
}Expand description
Built-in action dispatched by shells when a notification response arrives.
Fields
response: NotificationResponseTrait Implementations
Sourceimpl Clone for NotificationResponseReceived
impl Clone for NotificationResponseReceived
Sourcefn clone(&self) -> NotificationResponseReceived
fn clone(&self) -> NotificationResponseReceived
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotificationResponseReceived
impl Debug for NotificationResponseReceived
Sourceimpl<'de> Deserialize<'de> for NotificationResponseReceived
impl<'de> Deserialize<'de> for NotificationResponseReceived
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for NotificationResponseReceived
impl PartialEq for NotificationResponseReceived
Sourcefn eq(&self, other: &NotificationResponseReceived) -> bool
fn eq(&self, other: &NotificationResponseReceived) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for NotificationResponseReceived
impl StructuralPartialEq for NotificationResponseReceived