pub struct NfcWriteRequest {
pub records: Vec<NfcRecord>,
pub message: Option<String>,
pub timeout_ms: Option<u64>,
pub make_read_only: bool,
}Expand description
NFC write request. Hosts may require the user to tap a writable tag after this operation starts.
Fields
records: Vec<NfcRecord>message: Option<String>timeout_ms: Option<u64>make_read_only: boolTrait Implementations
Sourceimpl Clone for NfcWriteRequest
impl Clone for NfcWriteRequest
Sourcefn clone(&self) -> NfcWriteRequest
fn clone(&self) -> NfcWriteRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NfcWriteRequest
impl Debug for NfcWriteRequest
Sourceimpl Default for NfcWriteRequest
impl Default for NfcWriteRequest
Sourcefn default() -> NfcWriteRequest
fn default() -> NfcWriteRequest
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for NfcWriteRequest
impl<'de> Deserialize<'de> for NfcWriteRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for NfcWriteRequest
impl PartialEq for NfcWriteRequest
Sourcefn eq(&self, other: &NfcWriteRequest) -> bool
fn eq(&self, other: &NfcWriteRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for NfcWriteRequest
impl Serialize for NfcWriteRequest
impl Eq for NfcWriteRequest
impl StructuralPartialEq for NfcWriteRequest