ActionRegistry

Struct ActionRegistry 

pub struct ActionRegistry<S: AppState> { /* private fields */ }
A per-frame collection of action handlers registered during widget building.

ActionRegistry is populated by BuildCtx::bind calls. After the widget tree is built, the registry is absorbed into the Runtime via Runtime::absorb_registry.

Implementations

Source

impl<S: AppState> ActionRegistry<S>

pub fn new() -> Self

pub fn register<A: Action, H: IntoHandler<S, A> + Send + Sync + 'static>( &mut self, handler: H, )

pub fn into_runtime_reducers(self) -> HashMap<ActionId, Vec<BoxedReducer>>