Module selection

Module selection 

Coordinated selection across read-only text descendants.

Structs

SelectionRegionController
Stable handle used to inspect or update a selection region’s retained state.
TextRegionPosition
A position in one selectable descendant of a SelectionRegion.
TextRegionSelection
A directional selection which can span several read-only text nodes.

Enums

SelectionRegionCommand
Programmatic operation for a selection region.
SelectionRegionError