Module custom_render

Module custom_render 

Custom render object trait for CustomNode.

Allows third-party or application-specific nodes to participate in hit-testing, event handling, and painting without requiring changes to the core IR enum variants.

Structs

CustomEventResult
Result of custom event handling.
CustomHitResult
Result of a custom hit-test.
RenderObjectHolder
Wrapper that allows Arc<dyn CustomRenderObject> to be stored as Arc<dyn Any + Send + Sync> inside the dependency-free fission-ir crate.

Traits

CustomRenderObject
Extension point for custom nodes that need to participate in rendering, hit-testing, and event handling.

Functions

downcast_render_object
Try to recover an Arc<dyn CustomRenderObject> from an AnyRenderObject stored in CoreIR::custom_render_objects.