pub struct CustomEventResult {
pub handled: bool,
pub actions: Vec<(NodeId, ActionEnvelope)>,
}Expand description
Result of custom event handling.
Fields
handled: boolIf true the event was consumed and should not propagate further.
actions: Vec<(NodeId, ActionEnvelope)>Zero or more actions to dispatch as a consequence of the event.
Implementations
Sourceimpl CustomEventResult
impl CustomEventResult
Sourcepub fn consumed_with(actions: Vec<(NodeId, ActionEnvelope)>) -> Self
pub fn consumed_with(actions: Vec<(NodeId, ActionEnvelope)>) -> Self
The event was consumed and produced actions.