pub struct ActionScope {
pub id: ActionScopeId,
pub child: Box<Node>,
}Expand description
Tags a subtree with a raw action dispatch scope.
The widget does not change layout or paint output. It inserts a semantics
wrapper so descendants dispatch actions with this scope in their
ActionInput.
Fields
id: ActionScopeIdchild: Box<Node>Implementations
Sourceimpl ActionScope
impl ActionScope