Module context_menu

Module context_menu 

Structs

ContextMenu
A popup menu shown for a secondary click or other contextual activation.
ContextMenuItem
A selectable context menu item.
ContextMenuRegion
Widget wrapper that gives any subtree a context menu.
TextContextMenuConfig

Enums

ContextMenuEntry
A row inside a ContextMenu.
TextContextMenuAction
Standard editing/selection commands used by built-in text context menus.