GridItem

Struct GridItem 

pub struct GridItem {
    pub id: Option<NodeId>,
    pub child: Box<Node>,
    pub row_start: GridPlacement,
    pub row_end: GridPlacement,
    pub col_start: GridPlacement,
    pub col_end: GridPlacement,
}
A child placed within a Grid at a specific row/column position.

Use cell to set the row and column, and span to span multiple tracks.

Example

GridItem::new(content)
    .cell(2, 1)       // row 2, column 1
    .span(1, 2)        // span 1 row, 2 columns

Fields

id: Option<NodeId>

Explicit node identity.

child: Box<Node>

The child widget placed in the grid cell.

row_start: GridPlacement

Starting row (1-indexed line or Auto).

row_end: GridPlacement

Ending row (Auto or Span).

col_start: GridPlacement

Starting column (1-indexed line or Auto).

col_end: GridPlacement

Ending column (Auto or Span).

Implementations

Source

impl GridItem

pub fn new(child: Node) -> Self

pub fn cell(self, row: i16, col: i16) -> Self

pub fn span(self, row_span: u16, col_span: u16) -> Self

pub fn into_node(self) -> Node