pub struct SelectionRegionControls {
pub word_selection_on_double_click: bool,
pub paragraph_selection_on_triple_click: bool,
pub word_selection_on_long_press: bool,
pub platform_style: SelectionPlatformStyle,
pub context_menu: TextContextMenuConfig,
pub touch_slop: f32,
pub edge_auto_scroll: bool,
pub edge_auto_scroll_threshold: f32,
pub edge_auto_scroll_step: f32,
pub selection_controls: TextSelectionControls,
pub magnifier_configuration: TextMagnifierConfiguration,
}Expand description
Interaction and platform-presentation policy for a coordinated selection.
Fields
word_selection_on_double_click: boolparagraph_selection_on_triple_click: boolword_selection_on_long_press: boolplatform_style: SelectionPlatformStyletouch_slop: f32Minimum touch/stylus movement before a drag changes the selection.
edge_auto_scroll: boolWhether selection drags near a scroll viewport edge advance that viewport.
edge_auto_scroll_threshold: f32Distance from a viewport edge that activates automatic scrolling.
edge_auto_scroll_step: f32Logical pixels advanced for each pointer-move near an edge.
selection_controls: TextSelectionControlsmagnifier_configuration: TextMagnifierConfigurationTrait Implementations
Sourceimpl Clone for SelectionRegionControls
impl Clone for SelectionRegionControls
Sourcefn clone(&self) -> SelectionRegionControls
fn clone(&self) -> SelectionRegionControls
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SelectionRegionControls
impl Debug for SelectionRegionControls
Sourceimpl Default for SelectionRegionControls
impl Default for SelectionRegionControls
Sourceimpl<'de> Deserialize<'de> for SelectionRegionControlswhere
SelectionRegionControls: Default,
impl<'de> Deserialize<'de> for SelectionRegionControlswhere
SelectionRegionControls: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more