Switch

Struct Switch 

pub struct Switch {
    pub id: Option<NodeId>,
    pub checked: bool,
    pub on_toggle: Option<ActionEnvelope>,
}
A boolean toggle rendered as a sliding thumb on a track.

Visually similar to iOS/Material “switch” controls. The on_toggle action is dispatched when the user taps the switch; the application toggles checked in the reducer.

Example

Switch {
    checked: view.state.dark_mode,
    on_toggle: Some(ctx.bind(ToggleDarkMode, handler as fn(&mut S, ToggleDarkMode))),
    ..Default::default()
}

Fields

id: Option<NodeId>

Explicit node identity.

checked: bool

Current on/off state.

on_toggle: Option<ActionEnvelope>

Action dispatched when the switch is tapped.

Implementations

Source

impl Switch

pub fn into_node(self) -> Node