Effects

Struct Effects 

pub struct Effects<'a, S: AppState> {
    pub out: Vec<EffectEnvelope>,
    /* private fields */
}
Builder for emitting side-effects from within a reducer.

Effects accumulates EffectEnvelope values that the runtime collects after the reducer returns. Each effect can carry optional on_ok and on_err callbacks.

Example

fn handle_save(
    state: &mut MyState,
    _action: Save,
    ctx: &mut ReducerContext<MyState>,
) {
    ctx.effects.http_get("https://api.example.com/save")
        .on_ok(ctx.effects.bind(SaveOk, handle_save_ok as fn(&mut MyState, SaveOk)))
        .on_err(ctx.effects.bind(SaveErr, handle_save_err as fn(&mut MyState, SaveErr)));
}

Fields

out: Vec<EffectEnvelope>

Accumulated effect envelopes, drained by the runtime after the reducer.

Implementations

Source

impl<'a, S: AppState> Effects<'a, S>

pub fn new(next_req_id: u64, registry: &'a mut ActionRegistry<S>) -> Self

pub fn new_headless(next_req_id: u64) -> Self

pub fn bind<A: Action, H>(&mut self, action: A, handler: H) -> ActionEnvelope
where H: IntoHandler<S, A> + Send + Sync + 'static,

pub fn add(&mut self, effect: SystemEffect) -> u64

pub fn system_effect( &mut self, effect: SystemEffect, ) -> EffectBuilder<'_, 'a, S>

pub fn http_get(&mut self, url: impl Into<String>) -> EffectBuilder<'_, 'a, S>

pub fn file_read(&mut self, path: impl Into<String>) -> EffectBuilder<'_, 'a, S>

pub fn cancel(&mut self, req_id: u64)

pub fn release_resource(&mut self, resource_id: u64)