ActionInput

Enum ActionInput 

pub enum ActionInput {
Show 16 variants None, JobOk { job_name: String, req_id: u64, payload: Vec<u8>, }, JobErr { job_name: String, req_id: u64, payload: Option<Vec<u8>>, message: Option<String>, }, ServiceStarted { service_name: String, slot_key: String, instance_id: u64, }, ServiceStartFailed { service_name: String, slot_key: String, payload: Option<Vec<u8>>, message: Option<String>, }, ServiceEvent { service_name: String, slot_key: String, instance_id: u64, payload: Vec<u8>, }, ServiceStopped { service_name: String, slot_key: String, instance_id: u64, }, ServiceCommandOk { service_name: String, slot_key: String, instance_id: u64, req_id: u64, payload: Option<Vec<u8>>, }, ServiceCommandErr { service_name: String, slot_key: String, instance_id: u64, req_id: u64, payload: Option<Vec<u8>>, message: Option<String>, }, CapabilityOk { capability: String, req_id: u64, payload: Vec<u8>, }, CapabilityErr { capability: String, req_id: u64, payload: Option<Vec<u8>>, message: Option<String>, }, TimerTick { payload: Vec<u8>, }, Pointer { x: f32, y: f32, delta_x: f32, delta_y: f32, }, Drop { paths: Vec<String>, x: f32, y: f32, }, InternalDrop { payload: Vec<u8>, x: f32, y: f32, }, ScopedRaw { scope_id: u128, target: NodeId, input: Box<ActionInput>, },
}
Extra input data passed alongside an action dispatch.

When the platform delivers an effect result or a drag-and-drop event, it attaches an ActionInput so the reducer can access the associated data without encoding it in the action payload.

Example

fn on_file_loaded(
    state: &mut MyState,
    _action: FileLoaded,
    ctx: &mut ReducerContext<MyState>,
) {
    if let Some(bytes) = ctx.input.as_bytes() {
        state.file_contents = String::from_utf8_lossy(bytes).into_owned();
    }
}

Variants



None

No extra input.



JobOk

A typed async job completed successfully.

Fields

job_name: String
req_id: u64
payload: Vec<u8>


JobErr

A typed async job failed.

Fields

job_name: String
req_id: u64
payload: Option<Vec<u8>>
message: Option<String>


ServiceStarted

A service slot started successfully.

Fields

service_name: String
slot_key: String
instance_id: u64


ServiceStartFailed

A service slot failed to start.

Fields

service_name: String
slot_key: String
payload: Option<Vec<u8>>
message: Option<String>


ServiceEvent

A running service emitted an event.

Fields

service_name: String
slot_key: String
instance_id: u64
payload: Vec<u8>


ServiceStopped

A running service stopped.

Fields

service_name: String
slot_key: String
instance_id: u64


ServiceCommandOk

A service command completed successfully.

Fields

service_name: String
slot_key: String
instance_id: u64
req_id: u64
payload: Option<Vec<u8>>


ServiceCommandErr

A service command failed.

Fields

service_name: String
slot_key: String
instance_id: u64
req_id: u64
payload: Option<Vec<u8>>
message: Option<String>


CapabilityOk

A typed capability operation succeeded.

Fields

capability: String
req_id: u64
payload: Vec<u8>


CapabilityErr

A typed capability operation failed.

Fields

capability: String
req_id: u64
payload: Option<Vec<u8>>
message: Option<String>


TimerTick

A timer resource fired.

Fields

payload: Vec<u8>


Pointer

Pointer coordinates and deltas (used by drag/gesture handlers).

Fields

delta_x: f32
delta_y: f32


Drop

External file drop (e.g. from the OS file manager).

Fields

paths: Vec<String>


InternalDrop

Internal drag-and-drop with an opaque byte payload.

Fields

payload: Vec<u8>


ScopedRaw

The action was dispatched from a subtree with a raw action scope.

Fields

scope_id: u128
target: NodeId

Implementations

Source

impl ActionInput

pub fn scoped_raw(scope_id: u128, target: NodeId, input: ActionInput) -> Self

pub fn action_scope_id(&self) -> Option<u128>

pub fn scoped_target(&self) -> Option<NodeId>

pub fn unscoped(&self) -> &ActionInput

pub fn as_bytes(&self) -> Option<&[u8]>

pub fn as_pointer(&self) -> Option<(f32, f32, f32, f32)>

pub fn as_drop_paths(&self) -> Option<&[String]>

pub fn as_internal_drop(&self) -> Option<&[u8]>

pub fn job_ok<J: JobSpec>(&self, job: JobRef<J>) -> Option<J::Ok>

pub fn job_err<J: JobSpec>(&self, job: JobRef<J>) -> Option<J::Err>

pub fn job_error_message<J: JobSpec>(&self, job: JobRef<J>) -> Option<&str>

pub fn capability_ok<C: OperationCapability>( &self, capability: CapabilityType<C>, ) -> Option<C::Ok>

pub fn capability_error<C: OperationCapability>( &self, capability: CapabilityType<C>, ) -> Option<C::Err>

pub fn capability_error_message<C: OperationCapability>( &self, capability: CapabilityType<C>, ) -> Option<&str>

pub fn service_event<S: ServiceSpec>( &self, service: ServiceType<S>, ) -> Option<S::Event>

pub fn service_start_err<S: ServiceSpec>( &self, service: ServiceType<S>, ) -> Option<S::StartErr>

pub fn service_start_error_message<S: ServiceSpec>( &self, service: ServiceType<S>, ) -> Option<&str>

pub fn service_command_ok<S: ServiceSpec>( &self, service: ServiceType<S>, ) -> Option<S::CommandOk>

pub fn service_command_err<S: ServiceSpec>( &self, service: ServiceType<S>, ) -> Option<S::CommandErr>

pub fn timer_tick<T: DeserializeOwned>(&self) -> Option<T>

pub fn service_slot_key(&self) -> Option<&str>

pub fn service_instance_id(&self) -> Option<u64>