pub struct TextEditState {
pub buffer: TextBuffer,
pub caret: usize,
pub anchor: usize,
pub history: TextEditHistory,
pub preedit: Option<TextPreeditState>,
pub pending_model_sync: bool,
pub last_dispatched_cursor: Option<(usize, usize)>,
pub affordances: TextInputAffordanceState,
}Fields
buffer: TextBuffercaret: usizeanchor: usizehistory: TextEditHistorypreedit: Option<TextPreeditState>pending_model_sync: boollast_dispatched_cursor: Option<(usize, usize)>Last cursor position that was dispatched as a CursorChanged action. Used to deduplicate dispatches and prevent unnecessary model updates that could cause extra rebuild cycles.
affordances: TextInputAffordanceStateImplementations
Sourceimpl TextEditState
impl TextEditState
pub fn snapshot(&self) -> TextRestorationSnapshot
pub fn restore_snapshot(&mut self, snapshot: &TextRestorationSnapshot)
pub fn set_history_capacity(&mut self, capacity: usize)
pub fn committed_text(&self) -> String
pub fn sync_from_model(&mut self, semantic_value: &str)
pub fn selection_range(&self) -> (usize, usize)
pub fn clear_preedit(&mut self)
pub fn set_preedit(&mut self, text: String)
pub fn display_text(&self) -> (String, Option<(usize, usize)>)
pub fn apply_edit( &mut self, range: Range<usize>, new_text: &str, next_caret: usize, next_anchor: usize, ) -> String
pub fn undo(&mut self) -> Option<(String, usize, usize)>
pub fn redo(&mut self) -> Option<(String, usize, usize)>