pub struct TextEditState {
pub caret: usize,
pub anchor: usize,
pub history: TextEditHistory,
pub last_value: String,
pub pending_model_sync: bool,
pub last_dispatched_cursor: Option<(usize, usize)>,
}Fields
caret: usizeanchor: usizehistory: TextEditHistorylast_value: Stringpending_model_sync: boollast_dispatched_cursor: Option<(usize, usize)>Last cursor position that was dispatched as a CursorChanged action. Used to deduplicate dispatches and prevent unnecessary model updates that could cause extra rebuild cycles.