NFC host capabilities.
The core crate only defines portable typed requests, results, and capability identities. Shells decide which platform NFC APIs can satisfy them.
Structs
- Cancel
NfcSession Capability - Emulate
NfcTag Capability - GetNfc
Availability Capability - NfcAvailability
- NFC operation support reported by the active shell.
- NfcEmulation
Request - NFC card-emulation request for hosts that support it.
- NfcError
- Portable NFC error payload.
- NfcRecord
- Portable NDEF-like record payload.
- NfcScan
Request - One-shot NFC read request.
- NfcSession
Receipt - Receipt for write/emulation/session operations.
- NfcTag
- A tag returned by a scan operation.
- NfcTag
Discovered - Built-in action for host-delivered NFC tag events.
- NfcWrite
Request - NFC write request. Hosts may require the user to tap a writable tag after this operation starts.
- Scan
NfcTag Capability - Write
NfcTag Capability
Enums
- NfcRecord
Type Name Format - NFC Forum NDEF type-name-format value.
- NfcTechnology
- NFC technology family requested by an app or discovered on a tag.