SelectionRegionControls

Struct SelectionRegionControls 

pub struct SelectionRegionControls {
    pub word_selection_on_double_click: bool,
    pub paragraph_selection_on_triple_click: bool,
    pub word_selection_on_long_press: bool,
    pub platform_style: SelectionPlatformStyle,
    pub context_menu: TextContextMenuConfig,
    pub touch_slop: f32,
    pub edge_auto_scroll: bool,
    pub edge_auto_scroll_threshold: f32,
    pub edge_auto_scroll_step: f32,
    pub selection_controls: TextSelectionControls,
    pub magnifier_configuration: TextMagnifierConfiguration,
}
Interaction and platform-presentation policy for a coordinated selection.

Fields

word_selection_on_double_click: boolparagraph_selection_on_triple_click: boolword_selection_on_long_press: boolplatform_style: SelectionPlatformStylecontext_menu: TextContextMenuConfigtouch_slop: f32

Minimum touch/stylus movement before a drag changes the selection.

edge_auto_scroll: bool

Whether selection drags near a scroll viewport edge advance that viewport.

edge_auto_scroll_threshold: f32

Distance from a viewport edge that activates automatic scrolling.

edge_auto_scroll_step: f32

Logical pixels advanced for each pointer-move near an edge.

selection_controls: TextSelectionControlsmagnifier_configuration: TextMagnifierConfiguration